summaryrefslogtreecommitdiff
path: root/src/widget.cpp
diff options
context:
space:
mode:
authorbelugas <belugas@openttd.org>2008-08-02 02:50:40 +0000
committerbelugas <belugas@openttd.org>2008-08-02 02:50:40 +0000
commitd0d285ed573dd7550a1518d12d506ff41b04ec00 (patch)
treef5a9137aaec437e6ee9e6dc8d25ae24f58340948 /src/widget.cpp
parentc5cecdd2e3b91b70f027ece6eacc23376c3bbb83 (diff)
downloadopenttd-d0d285ed573dd7550a1518d12d506ff41b04ec00.tar.xz
(svn r13920) -Codechange: uniformise the definition with the declaration of DrawFrameRect
Diffstat (limited to 'src/widget.cpp')
-rw-r--r--src/widget.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/widget.cpp b/src/widget.cpp
index 92c402e5d..04540d64a 100644
--- a/src/widget.cpp
+++ b/src/widget.cpp
@@ -167,15 +167,15 @@ int GetWidgetFromPos(const Window *w, int x, int y)
* @param top Top edge of the frame
* @param right Right edge of the frame
* @param bottom Bottom edge of the frame
* @param ctab Colour table to use. @see _colour_gradient
* @param flags Flags controlling how to draw the frame. @see FrameFlags
*/
-void DrawFrameRect(int left, int top, int right, int bottom, int ctab, FrameFlags flags)
+void DrawFrameRect(int left, int top, int right, int bottom, int color, FrameFlags flags)
{
- uint dark = _colour_gradient[ctab][3];
- uint medium_dark = _colour_gradient[ctab][5];
- uint medium_light = _colour_gradient[ctab][6];
- uint light = _colour_gradient[ctab][7];
+ uint dark = _colour_gradient[color][3];
+ uint medium_dark = _colour_gradient[color][5];
+ uint medium_light = _colour_gradient[color][6];
+ uint light = _colour_gradient[color][7];
if (flags & FR_TRANSPARENT) {
GfxFillRect(left, top, right, bottom, PALETTE_TO_TRANSPARENT, FILLRECT_RECOLOR);
@@ -167,15 +167,15 @@ int GetWidgetFromPos(const Window *w, int x, int y)
* @param right Right edge of the frame
* @param bottom Bottom edge of the frame
- * @param ctab Colour table to use. @see _colour_gradient
+ * @param color Colour table to use. @see _colour_gradient
* @param flags Flags controlling how to draw the frame. @see FrameFlags
*/